@@ -4,9 +4,11 @@
 """Package containing :py:class:`QMenu` Context Menus."""
 
 __all__ = (
+    'AccountContextMenu',
     'HelpContextMenu',
     'ToolsContextMenu',
 )
 
+from .account import AccountContextMenu
 from .help import HelpContextMenu
 from .tools import ToolsContextMenu
